pitchtools.ObjectSet
====================

.. abjad-lineage:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet

.. autoclass:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.intersection
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.isdisjoint
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.issubset
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.issuperset
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.symmetric_difference
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.union
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__cmp__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__rand__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__ror__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__rsub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__rxor__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__sub__
   :noindex:

.. automethod:: abjad.tools.pitchtools.ObjectSet.ObjectSet.ObjectSet.__xor__
   :noindex:
